# scs_philips_hue
_A light bulb moment... connecting Philips Hue light bulbs to South Coast Science environmental data sources_

Detailed information at the [scs_philips_hue wiki](https://github.com/south-coast-science/scs_philips_hue/wiki).

The name Philips Hue is the property of its owner:
http://www2.meethue.com/en-gb
